Class: Aws::Sustainability::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Sustainability::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sustainability/client.rb
Overview
An API client for Sustainability. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Sustainability::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_estimated_carbon_emissions(params = {}) ⇒ Types::GetEstimatedCarbonEmissionsResponse
Returns estimated carbon emission values based on customer grouping and filtering parameters.
-
#get_estimated_carbon_emissions_dimension_values(params = {}) ⇒ Types::GetEstimatedCarbonEmissionsDimensionValuesResponse
Returns the possible dimension values available for a customer’s account.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-sustainability/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
766 767 768 |
# File 'lib/aws-sdk-sustainability/client.rb', line 766 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
769 770 771 |
# File 'lib/aws-sdk-sustainability/client.rb', line 769 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 |
# File 'lib/aws-sdk-sustainability/client.rb', line 739 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Sustainability') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sustainability' context[:gem_version] = '1.1.0' Seahorse::Client::Request.new(handlers, context) end |
#get_estimated_carbon_emissions(params = {}) ⇒ Types::GetEstimatedCarbonEmissionsResponse
Returns estimated carbon emission values based on customer grouping and filtering parameters. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
628 629 630 631 |
# File 'lib/aws-sdk-sustainability/client.rb', line 628 def get_estimated_carbon_emissions(params = {}, = {}) req = build_request(:get_estimated_carbon_emissions, params) req.send_request() end |
#get_estimated_carbon_emissions_dimension_values(params = {}) ⇒ Types::GetEstimatedCarbonEmissionsDimensionValuesResponse
Returns the possible dimension values available for a customer’s account. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
730 731 732 733 |
# File 'lib/aws-sdk-sustainability/client.rb', line 730 def get_estimated_carbon_emissions_dimension_values(params = {}, = {}) req = build_request(:get_estimated_carbon_emissions_dimension_values, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
759 760 761 |
# File 'lib/aws-sdk-sustainability/client.rb', line 759 def waiter_names [] end |